@@ -4,27 +4,34 @@ from typing import Dict, Optional
 
 import requests
 from notecoin.okex.common import exceptions
-from notecoin.okex.v5 import consts as c
 from notecoin.okex.v5 import utils
 
+GET = "GET"
+POST = "POST"
+DELETE = "DELETE"
+API_URL = 'https://www.okex.com'
+SERVER_TIMESTAMP_URL = '/api/general/v5/time'
+
 
 class BaseClient(object):
 
-    def __init__(self, api_key, api_secret_key, passphrase, use_server_time=False, test=False, first=False):
+    def __init__(self, api_key, api_secret_key, passphrase, use_server_time=False, test=False, first=False,
+                 api_url=None, flag='1', proxy=None):
         self.API_KEY = api_key
         self.API_SECRET_KEY = api_secret_key
         self.PASSPHRASE = passphrase
         self.use_server_time = use_server_time
+        self.flag = flag
         self.first = first
         self.test = test
-        self.api_url = c.API_URL
-        self.proxy = None
+        self.api_url = api_url or API_URL
+        self.proxy = proxy
 
-    def _request(self, method, request_path, params, cursor=False):
-        if method == c.GET:
-            request_path = request_path + utils.parse_params_to_str(params)
+    def _request(self, method, uri, params, cursor=False):
+        if method == GET:
+            uri = uri + utils.parse_params_to_str(params)
 
-        url = self.api_url + request_path
+        url = self.api_url + uri
 
         # 获取本地时间
         timestamp = utils.get_timestamp()
@@ -35,12 +42,12 @@ class BaseClient(object):
             timestamp = self._get_timestamp()
 
         if isinstance(params, str):
-            body = params if method == c.POST else ""
+            body = params if method == POST else ""
         elif isinstance(params, dict):
-            body = json.dumps(params) if method == c.POST else ""
+            body = json.dumps(params) if method == POST else ""
         else:
-            body = json.dumps(params) if method == c.POST else ""
-        sign = utils.sign(utils.pre_hash(timestamp, method, request_path, str(body)), self.API_SECRET_KEY)
+            body = json.dumps(params) if method == POST else ""
+        sign = utils.sign(utils.pre_hash(timestamp, method, uri, str(body)), self.API_SECRET_KEY)
         header = utils.get_header(self.API_KEY, sign, timestamp, self.PASSPHRASE)
 
         if self.test:
@@ -54,17 +61,17 @@ class BaseClient(object):
 
         # send request
         response = None
-        if method == c.GET:
+        if method == GET:
             if self.proxy is None:
                 response = requests.get(url, headers=header)
             else:
                 response = requests.get(url, headers=header, proxies=self.proxy)
-        elif method == c.POST:
+        elif method == POST:
             if self.proxy is None:
                 response = requests.post(url, data=body, headers=header)
             else:
                 response = requests.post(url, data=body, headers=header, proxies=self.proxy)
-        elif method == c.DELETE:
+        elif method == DELETE:
             if self.proxy is None:
                 response = requests.delete(url, headers=header)
             else:
@@ -97,12 +104,10 @@ class BaseClient(object):
         return self._request(method, request_path, params, cursor)
 
     def _get_timestamp(self):
-        url = self.api_url + c.SERVER_TIMESTAMP_URL
-        if self.proxy is None:
-            response = requests.get(url)
-        else:
-            response = requests.get(url, proxies=self.proxy)
+        url = self.api_url + SERVER_TIMESTAMP_URL
+        response = requests.get(url, proxies=self.proxy)
         if response.status_code == 200:
+            # return response.json()['ts']
             return response.json()['iso']
         else:
             return ""
