@@ -2,6 +2,14 @@
 from enum import Enum
 
 
+class Response:
+    def __init__(self, data=None):
+        data = data or {}
+        self.code = data['code']
+        self.msg = data['msg']
+        self.data = data['data']
+
+
 class BillType(Enum):
     # 划转
     TRANSFER = 1
